@@ -4682,7 +4682,80 @@ abuse_words = [
     "leg7",
     "leg8",
     "leg9",
-    "hack"
+    "xxx0",
+    "xxx1",
+    "xxx2",
+    "xxx3",
+    "xxx4",
+    "xxx5",
+    "xxx6",
+    "xxx7",
+    "xxx8",
+    "xxx9",
+    "xxxa",
+    "xxxb",
+    "xxxc",
+    "xxxd",
+    "xxxe",
+    "xxxf",
+    "xxxg",
+    "xxxh",
+    "xxxi",
+    "xxxj",
+    "xxxk",
+    "xxxl",
+    "xxxm",
+    "xxxn",
+    "xxxo",
+    "xxxp",
+    "xxxq",
+    "xxxr",
+    "xxxs",
+    "xxxt",
+    "xxxu",
+    "xxxv",
+    "xxxw",
+    "xxxy",
+    "xxxz"
+]
+
+same_chars = [
+    "0000",
+    "1111",
+    "2222",
+    "3333",
+    "4444",
+    "5555",
+    "6666",
+    "7777",
+    "8888",
+    "9999",
+    "aaaa",
+    "bbbb",
+    "cccc",
+    "dddd",
+    "eeee",
+    "ffff",
+    "gggg",
+    "hhhh",
+    "iiii",
+    "jjjj",
+    "kkkk",
+    "llll",
+    "mmmm",
+    "nnnn",
+    "oooo",
+    "pppp",
+    "qqqq",
+    "rrrr",
+    "ssss",
+    "tttt",
+    "uuuu",
+    "vvvv",
+    "wwww",
+    "xxxx",
+    "yyyy",
+    "zzzz"
 ]
 
 stop_words = english_words + abuse_words
